@@ -314,7 +314,7 @@ class Cursor(DBAPICursor):
         _logger.info("fetching all from overriden method")
         self._data = list()
         while len(self._data) < self.rowcount():
-            _logger.info("fetching next batch")
+            _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
             self._data = self._data + rows
         return self._data
@@ -340,7 +340,7 @@ class Cursor(DBAPICursor):
         size = min(size, self.rowcount())
         self._data = list()
         while len(self._data) < size:
-            _logger.info("fetching next batch")
+            _logger.info("fetching next batch from fetch many")
             rows = self.fetch_batch()
             self._data = self._data + rows
         return self._data if len(self._data) == size else self._data[0:size]
